# compairingnumber
**This package help you to find greater and smaller number between three numbers

# Getting started
## Installing the Package
> pip install compairingnumber

## using the package
` import compairingnumber as cn `

# Functions Provided
